.. :changelog:

Release History
===============

0.1.6 (2017-05-09)
++++++++++++++++++
* Rename documentdb module to cosmosdb.

0.1.5 (2017-05-05)
++++++++++++++++++

* Added support for documentdb data-plane APIs:
  database and collection management
* Added support for enabling automatic failover on database accounts
* Added support for new consistency policy ConsistentPrefix
* Upgraded pypi package dependency for azure-mgmt-documentdb to 0.1.3

0.1.4 (2017-04-28)
++++++++++++++++++

* New packaging system.

0.1.3 (2017-04-17)
++++++++++++++++++

* Apply core changes required for API profile support (#2834)

0.1.2 (2017-04-03)
++++++++++++++++++

* DocumentDB: Adding support for listing connection strings (#2580)
* Fix TypeErrors in DocDB (#2566)

0.1.1b2 (2017-02-22)
+++++++++++++++++++++

* Documentation updates.


0.1.1b1 (2017-02-17)
+++++++++++++++++++++

* Initial release.

